---
date: 2024-02-02
authors: [matt]
description: >
  Reuse traces too!
categories:
  - Release
links:
---

# ✨ Layout Reuse Keeps Getting Better 🚀

Now with traces and vias 👌

<picture>
    <source type="image/avif" srcset="/assets/images/trace-reuse.avif" />
    <img src="/assets/images/trace-reuse.gif" />
</picture>

Happy designing! 🎉

Matt
